.. _dtu_config:

DTU config
=======================================
This package provides a configuration class to get, process, edit and store
user input.

Documentation
-------------

.. toctree::
   :caption: Developer's guide
   :maxdepth: 2

   dev

.. toctree::
    :caption: User's guide
    :maxdepth: 2

    users

.. toctree::
    :caption: API
    :maxdepth: 2

    API


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
